@@ -1,4 +1,4 @@
-from controller import Emitter, Camera
+from controller import Emitter, Camera, GPS
 from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
 from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDrone
@@ -38,10 +38,6 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         :param msg: The message to send
         :return: None
         """
-
-        if 5.0 - (self.getTime() % 5.0) != 0:
-            return 0
-
         total_time = 0
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
 
@@ -98,9 +94,20 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             f_led.set(led_on)
             led_on = not led_on
 
-    def get_image_array(self):
+    def get_image_vector_every(self, n):
+        t = self.getTime() % 5.0
+        if t != 0.0:
+            return []
+
         camera: Camera = self.devices['camera']['device']
-        return camera.getImageArray()
+        image = camera.getImage()
+        width = camera.getWidth()
+        height = camera.getHeight()
+
+        image_vector = [[[camera.imageGetRed(image, width, x, y),
+                         camera.imageGetGreen(image, width, x, y),
+                         camera.imageGetBlue(image, width, x, y)] for y in range(height)] for x in range(width)]
+        return image_vector
 
     def run(self):
         # Wait a second before starting
@@ -142,7 +149,8 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # t.run()
 
             # Send messages
-            transmit_time = self.send_msg(self.get_image_array(), emitter_devices)
+            image_rgb_vector = self.get_image_vector_every(5)
+            transmit_time = self.send_msg(image_rgb_vector, emitter_devices)
             # print("Transmit time:", transmit_time)
 
             # Receive messages
@@ -165,10 +173,15 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
                                      [humidity_max], [humidity_min], [humidity_avg]]).reshape(1, -1)
             # print(self.model.predict(input_vector))
 
+
 class AutopilotMavic2DJI(AutopilotControlledDrone):
-    def __init__(self, devices):
+    def __init__(self, devices, probe: FlockAIProbe=None, model=None):
         super().__init__(devices)
 
+    def get_coordinates(self):
+        gps: GPS = self.devices['gps']['device']
+        return gps.getValues()
+
     def run(self):
         # Wait a second before starting
         while self.step(self.basic_time_step) != -1:
@@ -177,4 +190,5 @@ class AutopilotMavic2DJI(AutopilotControlledDrone):
 
         while self.step(self.basic_time_step) != -1:
             # For now just actuate
+            print(self.get_coordinates())
             self.actuate()
